@@ -13,23 +13,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
-import grpc  # type: ignore
-
-from google.cloud.contact_center_insights_v1.types import contact_center_insights
-from google.cloud.contact_center_insights_v1.types import resources
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
-from .base import ContactCenterInsightsTransport, DEFAULT_CLIENT_INFO
+import grpc  # type: ignore
+
+from google.cloud.contact_center_insights_v1.types import (
+    contact_center_insights,
+    resources,
+)
+
+from .base import DEFAULT_CLIENT_INFO, ContactCenterInsightsTransport
 
 
 class ContactCenterInsightsGrpcTransport(ContactCenterInsightsTransport):
@@ -63,6 +63,7 @@ class ContactCenterInsightsGrpcTransport(ContactCenterInsightsTransport):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -159,6 +160,7 @@ class ContactCenterInsightsGrpcTransport(ContactCenterInsightsTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -230,8 +232,7 @@ class ContactCenterInsightsGrpcTransport(ContactCenterInsightsTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -1193,5 +1194,9 @@ class ContactCenterInsightsGrpcTransport(ContactCenterInsightsTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("ContactCenterInsightsGrpcTransport",)
